"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ChannelIdService = void 0;
const typesystem_1 = require("@smallstack/typesystem");
class ChannelIdService {
    constructor(contextProvider) {
        this.contextProvider = contextProvider;
    }
    /**
     * Creates a channel id for receiving personal events like `unread messages`
     */
    createForPersonal(userId) {
        const resellerId = this.contextProvider.getCurrentResellerId();
        const tenantId = this.contextProvider.getCurrentTenantId();
        return `${resellerId}_${tenantId}_user_${userId}`;
    }
    /**
     * Creates channel ids for endpoints like `applications`, `cms` or `calendars`. Can be used to receive updates on CRUD operations.
     */
    createForCollection(collectionName) {
        switch (collectionName) {
            case typesystem_1.CollectionNames.COLLECTION_MESSAGES:
                return "messages";
            default: {
                const resellerId = this.contextProvider.getCurrentResellerId();
                const tenantId = this.contextProvider.getCurrentTenantId();
                return `${resellerId}_${tenantId}_${collectionName}`;
            }
        }
    }
}
exports.ChannelIdService = ChannelIdService;
//# sourceMappingURL=channel-id.service.js.map